/// <reference types="node" />
/// <reference types="urijs" />
import { Map, List } from "immutable";
import { Readable } from "stream";
import { Ref } from "./JSONSchemaInput";
import { Value, CompressedJSON } from "./CompressedJSON";
import { JSONSchemaStore } from "./JSONSchemaStore";
export declare function toString(source: string | Readable): Promise<string>;
export declare type StringInput = string | Readable;
export interface JSONTypeSource {
    kind: "json";
    name: string;
    samples: StringInput[];
    description?: string;
}
export interface TypeScriptTypeSource {
    kind: "typescript";
    sources: {
        [filename: string]: string;
    };
}
export interface SchemaTypeSource {
    kind: "schema";
    name: string;
    uris?: string[];
    schema?: StringInput;
}
export interface GraphQLTypeSource {
    kind: "graphql";
    name: string;
    schema: any;
    query: StringInput;
}
export declare type TypeSource = GraphQLTypeSource | JSONTypeSource | SchemaTypeSource | TypeScriptTypeSource;
export declare class InputData {
    private readonly _compressedJSON;
    private readonly _givenSchemaStore;
    private readonly _samples;
    private readonly _schemas;
    private readonly _graphQLs;
    private _schemaInputs;
    private _schemaSources;
    constructor(_compressedJSON: CompressedJSON, _givenSchemaStore: JSONSchemaStore | undefined);
    readonly jsonInputs: Map<string, {
        samples: Value[];
        description?: string;
    }>;
    readonly schemaInputs: Map<string, Ref>;
    readonly graphQLInputs: Map<string, {
        schema: any;
        query: string;
    }>;
    readonly schemaSources: List<[uri.URI, SchemaTypeSource]>;
    private addOtherTypeSource(source);
    private addSchemaTypeSource(schemaSource);
    addTypeSources(sources: TypeSource[]): Promise<boolean>;
    private addSchemaInput(name, ref);
    addSchemaInputs(): Promise<JSONSchemaStore | undefined>;
}
